import React, { useMemo } from 'react';
import { SettingsContainer } from '../../components/config';
import { layerTypes } from './components/layers';
import { Input } from '../../..';
import { GraphMetadata } from '@graphpolaris/shared/lib/data-access/statistics';
import { MapProps } from './mapvis';

export const MapSettings = ({
  configuration,
  graphMetadata,
  updateSettings,
}: {
  configuration: MapProps;
  graphMetadata: GraphMetadata;
  updateSettings: (val: any) => void;
}) => {
  // const spatialAttributes = useMemo(() => {
  //   if (!configuration.node) return [];
  //   return Object.entries(graphMetadata.nodes.types[configuration.node].attributes)
  //     .filter((kv) => kv[1].dimension === 'spatial')
  //     .map((kv) => kv[0]);
  // }, [configuration.node]);
  const spatialAttributes = useMemo(() => {
    if (!configuration.node) return [];
    return Object.entries(graphMetadata.nodes.types[configuration.node].attributes).map((kv) => kv[0]);
  }, [configuration.node]);

  return (
    <SettingsContainer>
      <span className="text-xs font-semibold">Data layer</span>
      <Input
        type="dropdown"
        value={configuration.layer}
        options={Object.keys(layerTypes)}
        onChange={(val) => updateSettings({ layer: val })}
      />

      <span className="text-xs font-semibold">Node Label</span>
      <Input
        type="dropdown"
        value={configuration.node}
        options={[...Object.keys(graphMetadata.nodes.types)]}
        disabled={Object.keys(graphMetadata.nodes.types).length < 1}
        onChange={(val) => updateSettings({ node: val })}
      />
      <span className="text-xs font-semibold">Location accessor (lat)</span>
      <Input
        type="dropdown"
        value={configuration.lat}
        options={[...spatialAttributes]}
        disabled={!configuration.node || spatialAttributes.length < 1}
        onChange={(val) => updateSettings({ lat: val })}
      />

      <span className="text-xs font-semibold">Location accessor (lon)</span>
      <Input
        type="dropdown"
        value={configuration.lon}
        options={[...spatialAttributes]}
        disabled={!configuration.node || spatialAttributes.length < 1}
        onChange={(val) => updateSettings({ lon: val })}
      />
    </SettingsContainer>
  );
};
